import os
from datetime import date, timedelta

from p2.store.client import Client
from p2.scheduler.Config import Config

class Calendar:

    def __init__(self, context: str = None):
        self.context = context
        self.p2_store_client = Client(os.environ.get('P2_STORE_URL'))
        self.config = Config()
        self.tomorrow = date.today() + timedelta(days=1)
        self.end = self.tomorrow+timedelta(days=self.config.look_ahead_period)
        self.calendar = dict()

    def get_available_dates(self):
        """Loads all scheduled sessions up to look_ahead_period"""
        for days in range(self.config.look_ahead_period):
            day = self.tomorrow+timedelta(days = days)
            if self._day_valid(day):
                self.calendar[day] = {'sessions':self.get_sessions_of_day(day)}

    def _day_valid(self, day: date) -> bool:
        """Returns true only if day is a 'schedulable' day"""
        if len(self.config.selected_week_days) > 0:
            if day.isoweekday() not in self.config.selected_week_days:
                return False
        return True

    def get_sessions_of_day( self, day: date) -> list:
        return self.p2_store_client.get_sessions(
            context=self.context,
            dom="%02d" % day.day,
            month="%02d" % day.month,
            year=day.year
            )

    def add_session(self, day: date, session: dict):
        self.calendar[day]['sessions'].append(session)
