import os
import logging

from p2.store.client import Client

class Config:

    def __init__(self, tag:str=None):

        self.log = logging.getLogger()
        p2_store_url = os.environ.get('P2_STORE_URL')
        if p2_store_url is None:
            raise("Envar P2_STORE_URL not found")
        self.p2_store_client = Client(p2_store_url)
        config = self.p2_store_client.get_config(
            component = 'p2.scheduler',
            tag = tag
        )
        if config is None:
            self.log.warning("No configuration found")
            config = dict()

        self.rules = config.get('rules', [])
        self.last_session_failed_rank = config.get('last_session_failed_rank', 10)
        self.spare_days_per_month = config.get('spare_days_per_month', 1)
        self.selected_week_days = config.get('selected_week_days', [2,3,4,5])
        self.max_tests_per_day = config.get('max_tests_per_day', 2)
        self.look_ahead_period = config.get('look_ahead_period', 30)
        self.target_priority_period = config.get('target_priority_period', [7,14,30])
        self.targets_priority = config.get('targets_priority', {})
        self.delete_sessions_after = config.get('delete_sessions_after', 300)
        self.delete_jobs_after = config.get('delete_jobs_after', 5)
        self.cronjobs = config.get('cronjobs', dict())
        self.shifts = config.get('shifts')
        if ( self.shifts is None ):
            raise Exception("Error, no shifts found in config")
