import logging
from p2.scheduler.Config import Config
from p2.tools.driver import get_driver
from abc import ABC, abstractmethod

class RuleEngine:
    """
        The P2 rules engine.

        Each scheduler instance has associated a set of rules.
        Rules are defined in the 'rules' config section.

        Synopsys:
            from p2.scheduler.rule import RuleEngine

            re = RuleEngine()
            re.apply_rules()
    """

    def __init__(self, config: Config, log=None):

        self.rules = []
        if log is None:
            log = logging.getLogger()

        for rule in config.rules:
            try:
                rule_obj = get_driver(
                    module='p2.scheduler.rule',
                    driver=rule,
                    class_name='Rule')
                self.rules.append(rule_obj)
            except Exception as e:
                log.error(f"Error getting rule {rule} object: {e}")

    def apply_rules(self, tests: list):
        """Calls the rank method for each defined rule.

            Tests should be a list of P2test objects.
        """
        for rule_obj in self.rules:
            rule_obj.rank(tests)


class Rule(ABC):
    """Abstract class for any p2.scheduler rule"""
    pass

    def rank(self, tests: list):
        """Updates the rank metric of each test in the set.
            Tests: list of P2test objects.
        """

